@@ -1,9 +1,9 @@
-/* bug-buddy bug submitting program
+/* Bug-buddy bug submitting program
  *
- * Copyright (C) 1999, 2000 Jacob Berkman
- * Copyright 2000 Helix Code, Inc.
+ * Copyright (C) 1999 - 2001 Jacob Berkman
+ * Copyright 2000, 2001 Ximian, Inc.
  *
- * Author:  Jacob Berkman  <jacob@helixcode.com>
+ * Author:  jacob berkman  <jacob@bug-buddy.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,52 +30,24 @@
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include <glade/glade.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk-pixbuf/gnome-canvas-pixbuf.h>
+#include <libgnomevfs/gnome-vfs.h>
 
 #include <tree.h>
 #include <parser.h>
 
 #include <sys/types.h>
 #include <signal.h>
-#include <dirent.h>
 
 #include "bug-buddy.h"
 #include "util.h"
 #include "distro.h"
-#include "glade-druid.h"
-#include "bts.h"
-#include "ctree-combo.h"
 
-/* libglade callbacks */
-gboolean on_front_page_next (GtkWidget *, GnomeDruid *);
-gboolean delete_me (GtkWidget *, GdkEventAny *, gpointer data);
-gboolean on_nature_page_next  (GtkWidget *, GnomeDruid *);
-gboolean on_debian_page_next (GtkWidget *page, GnomeDruid *druid);
-gboolean on_desc_page_next (GtkWidget *, GnomeDruid *);
-gboolean on_less_page_prepare (GtkWidget *, GtkWidget *);
-gboolean on_less_page_next    (GtkWidget *, GtkWidget *);
-gboolean on_misc_page_back    (GtkWidget *, GtkWidget *);
-gboolean on_the_druid_cancel  (GtkWidget *);
-gboolean on_complete_page_prepare (GtkWidget *, GtkWidget *);
-gboolean on_complete_page_finish  (GtkWidget *, GtkWidget *);
-gboolean on_gnome_page_prepare    (GtkWidget *, GtkWidget *);
-gboolean on_version_page_back (GtkWidget *page, GnomeDruid *druid);
-gboolean on_contact_page_next     (GtkWidget *, GtkWidget *);
-void on_version_list_select_row   (GtkCList *list, gint row, gint col,
-				   GdkEventButton *event, gpointer udata);
+#include "libglade-buddy.h"
 
-void update_selected_row      (GtkWidget *widget, gpointer data);
-void on_version_apply_clicked (GtkButton *button, gpointer data);
-void on_file_radio_toggled    (GtkWidget *radio, gpointer data);
-gboolean on_action_page_next  (GtkWidget *page, GtkWidget *druid);
-gboolean on_action_page_back  (GtkWidget *page, GnomeDruid *druid);
-gboolean on_action_page_prepare (GtkWidget *page, GnomeDruid *druid);
-GtkWidget *make_anim (gchar *widget_name, gchar *string1, 
-		      gchar *string2, gint int1, gint int2);
-GtkWidget *make_pixmap_button (gchar *widget_name, gchar *string1, 
-			       gchar *string2, gint int1, gint int2);
-gboolean on_more_page_next (GnomeDruidPage *page, GnomeDruid *druid);
-gboolean on_contact_page_prepare (GnomeDruidPage *page, GnomeDruid *druid);
-gboolean on_version_page_prepare (GnomeDruidPage *page, GnomeDruid *druid);
+#define DRUID_PAGE_HEIGHT 440
+#define DRUID_PAGE_WIDTH  600
 
 const gchar *severity[] = { 
 	N_("critical"),
@@ -101,9 +73,9 @@ const gchar *submit_type[] = {
 };
 
 const gchar *crash_type[] = {
-	N_("Collect debugging information from a crashed application"),
-	N_("Collect debugging information from a core file"),
-	N_("Skip this step"),
+	N_("crashed application"),
+	N_("core file"),
+	N_("nothing"),
 	NULL
 };
 
@@ -118,85 +90,46 @@ PoptData popt_data;
 DruidData druid_data;
 
 static const struct poptOption options[] = {
-	{ "name",        0, POPT_ARG_STRING, &popt_data.name,        0, N_("Name of contact"),                    N_("NAME") },
-	{ "email",       0, POPT_ARG_STRING, &popt_data.email,       0, N_("Email address of contact"),           N_("EMAIL") },
-	{ "package",     0, POPT_ARG_STRING, &popt_data.package,     0, N_("Package containing the program"),     N_("PACKAGE") },
-	{ "package-ver", 0, POPT_ARG_STRING, &popt_data.package_ver, 0, N_("Version of the package"),             N_("VERSION") },
-	{ "appname",     0, POPT_ARG_STRING, &popt_data.app_file,    0, N_("File name of crashed program"),       N_("FILE") },
-	{ "pid",         0, POPT_ARG_STRING, &popt_data.pid,         0, N_("PID of crashed program"),             N_("PID") },
-	{ "core",        0, POPT_ARG_STRING, &popt_data.core_file,   0, N_("Core file from program"),             N_("FILE") },
-	{ "include",     0, POPT_ARG_STRING, &popt_data.include_file,0, N_("Text file to include in the report"), N_("FILE") },
+	{ "name",        0, POPT_ARG_STRING, &popt_data.name,         0, N_("Name of contact"),                    N_("NAME") },
+	{ "email",       0, POPT_ARG_STRING, &popt_data.email,        0, N_("Email address of contact"),           N_("EMAIL") },
+	{ "package",     0, POPT_ARG_STRING, &popt_data.package,      0, N_("Package containing the program"),     N_("PACKAGE") },
+	{ "package-ver", 0, POPT_ARG_STRING, &popt_data.package_ver,  0, N_("Version of the package"),             N_("VERSION") },
+	{ "appname",     0, POPT_ARG_STRING, &popt_data.app_file,     0, N_("File name of crashed program"),       N_("FILE") },
+	{ "pid",         0, POPT_ARG_STRING, &popt_data.pid,          0, N_("PID of crashed program"),             N_("PID") },
+	{ "core",        0, POPT_ARG_STRING, &popt_data.core_file,    0, N_("Core file from program"),             N_("FILE") },
+	{ "include",     0, POPT_ARG_STRING, &popt_data.include_file, 0, N_("Text file to include in the report"), N_("FILE") },
 	{ NULL } 
 };
 
-static void
-save_entry (const char *name, const char *name2, const char *save_path)
-{
-	GtkWidget *w;
-	gchar *s;
+#if 0
+static char *proc_widgets[] = {
+	"gdb-binary-label", "gdb-binary-gnome-entry", "gdb-pid-label", "gdb-pid-entry", NULL
+};
 
-	w = GET_WIDGET (name);
-	s = gtk_entry_get_text (GTK_ENTRY (w));
-	gnome_config_set_string (save_path, s);
-	w = GET_WIDGET (name2);
-	if (GNOME_IS_FILE_ENTRY (w))
-		w = gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (w));
-	if (s && *s)
-		gnome_entry_prepend_history (GNOME_ENTRY (w), TRUE, s);
-	gnome_entry_save_history (GNOME_ENTRY (w));
-}
+static char *core_widgets[] = {
+	"gdb-core-label", "gdb-core-gnome-entry", NULL
+};
+
+static char *ident_widgets[] = {
+	"email-name-label", "email-name-gnome-entry", "email-email-label", "email-email-gnome-entry", 
+	"email-sendmail-label", "email-sendmail-gnome-entry", NULL
+};
+
+static char *addy_widgets[] = {
+	"email-to-label", "email-to-gnome-entry", "email-cc-label", "email-cc-gnome-entry",
+	"email-cc-toggle", NULL
+};
 
 static void
-save_config ()
-{
-	GtkWidget *w;
-	gboolean b;
-
-	save_entry ("name_entry",   "name_entry2",   "/bug-buddy/last/name");
-	save_entry ("email_entry",  "email_entry2",  "/bug-buddy/last/email_address");
-	save_entry ("file_entry",   "file_entry2",   "/bug-buddy/last/bugfile");
-	save_entry ("mailer_entry", "mailer_entry2", "/bug-buddy/last/mailer");
-
-	w = gnome_file_entry_gnome_entry (
-		GNOME_FILE_ENTRY (GET_WIDGET ("include_entry2")));
-	gnome_entry_save_history (GNOME_ENTRY (w));
-
-	b = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (SKIP_CONF));
-	gnome_config_set_bool ("/bug-buddy/last/skip_conf", b);
-	gnome_config_set_int ("/bug-buddy/last/submittype", 
-			      druid_data.submit_type);
-	b = gtk_toggle_button_get_active (
-		GTK_TOGGLE_BUTTON (GET_WIDGET ("cc_toggle")));
-	gnome_config_set_bool ("/bug-buddy/last/cc", b);
-			       
-	gnome_config_sync ();
-}
-
-static gboolean
-load_entry (const char *name, const char *name2,
-	    const char *path, const char *def)
-{
-	GtkWidget *w;
-	gboolean is_default;
-	gchar *s;
-
-	w = GET_WIDGET (name);
-	s = gnome_config_get_string_with_default (path, &is_default);
-	if (s)
-		gtk_entry_set_text (GTK_ENTRY (w), s);
-	else if (def)
-		gtk_entry_set_text (GTK_ENTRY (w), def);
-	g_free (s);
-	w = GET_WIDGET (name2);
-	if (GNOME_IS_FILE_ENTRY (w))
-		w = gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (w));
-	gnome_entry_load_history (GNOME_ENTRY (w));
-	return is_default;
-}
-
-static void
-load_config ()
+do_widgets (char **widgets, gboolean show)
 {
+	int i;
+	for (i = 0; widgets[i]; i++)
+		if (show)
+			gtk_widget_show (GET_WIDGET (widgets[i]));
+		else
+			gtk_widget_hide (GET_WIDGET (widgets[i]));
+#if 0
 	GtkWidget *w;
 	char *sendmail, *email = NULL;
 	gboolean b;
@@ -238,34 +171,40 @@ load_config ()
 	gtk_toggle_button_set_active (
 		GTK_TOGGLE_BUTTON (GET_WIDGET ("cc_toggle")),
 		gnome_config_get_bool ("/bug-buddy/last/cc=0"));
+#endif
 }
+#endif
 
 static gboolean
 update_crash_type (GtkWidget *w, gpointer data)
 {
 	CrashType new_type = GPOINTER_TO_INT (data);
-	GtkWidget *segv, *core;
+	GtkWidget *table, *box, *scrolled;
 
 	druid_data.crash_type = new_type;
-
-	segv = GET_WIDGET ("segv_table");
-	core = GET_WIDGET ("core_box");
+	
+	table = GET_WIDGET ("gdb-binary-table");
+	box = GET_WIDGET ("gdb-core-box");
+	scrolled = GET_WIDGET ("gdb-text-scrolled");
 
 	switch (new_type) {
 	case CRASH_DIALOG:
-		gtk_widget_show (segv);
-		gtk_widget_hide (core);
+		gtk_widget_hide (box);
+		gtk_widget_show (table);
+		gtk_widget_set_sensitive (scrolled, TRUE);
 		break;
 	case CRASH_CORE:
-		gtk_widget_show (core);
-		gtk_widget_hide (segv);
+		gtk_widget_hide (table);
+		gtk_widget_show (box);
+		gtk_widget_set_sensitive (scrolled, TRUE);
 		break;
 	case CRASH_NONE:
-		gtk_widget_hide (core);
-		gtk_widget_hide (segv);
+		gtk_widget_hide (table);
+		gtk_widget_hide (box);
+		gtk_widget_set_sensitive (scrolled, FALSE);
 		break;
 	}
-	
+
 	return FALSE;
 }
 
@@ -273,32 +212,101 @@ static gboolean
 update_submit_type (GtkWidget *w, gpointer data)
 {
 	SubmitType new_type = GPOINTER_TO_INT (data);
-	GtkWidget *box, *toggle, *entry;
-
+	GtkWidget *table, *box;
 	druid_data.submit_type = new_type;
 
-	box    = GET_WIDGET ("submit_to_box");
-	toggle = GET_WIDGET ("cc_toggle");
-	entry  = GET_WIDGET ("file_entry2");
-
-	gtk_widget_hide (box);
-	gtk_widget_hide (toggle);
-	gtk_widget_hide (entry);
-
+	table = GET_WIDGET ("email-to-table");
+	box = GET_WIDGET ("email-file-gnome-entry");
+	
 	switch (new_type) {
 	case SUBMIT_REPORT:
-		gtk_widget_show (box);
-		gtk_widget_show (toggle);
+		gtk_widget_hide (box);
+		gtk_widget_show (table);
 		break;
 	case SUBMIT_FILE:
-		gtk_widget_show (entry);
+		gtk_widget_hide (table);
+		gtk_widget_show (box);
+		break;
+	case SUBMIT_TO_SELF:
+		gtk_widget_hide (table);
+		gtk_widget_hide (box);
 		break;
 	default:
 		break;
 	}
+
+	gtk_widget_queue_resize (GET_WIDGET ("email-vbox"));
+
 	return FALSE;
 }
 
+void
+on_gdb_go_clicked (GtkWidget *w, gpointer data)
+{
+	druid_data.explicit_dirty = TRUE;
+	start_gdb ();
+}
+
+void
+on_gdb_stop_clicked (GtkWidget *button, gpointer data)
+{
+	GtkWidget *w;
+	if (!druid_data.fd)
+		return;
+
+	w = gnome_question_dialog (_("gdb has not finished getting the "
+				     "debugging information.\n"
+				     "Kill the gdb process (the stack trace "
+				     "will be incomplete)?"),
+				   NULL, NULL);
+
+	if (GNOME_YES == gnome_dialog_run_and_close (GNOME_DIALOG (w))) {
+		if (druid_data.gdb_pid == 0) {
+			g_warning (_("gdb has already exited"));
+			return;
+		}
+		kill (druid_data.gdb_pid, SIGTERM);
+		stop_gdb ();		
+		kill (druid_data.app_pid, SIGCONT);
+		druid_data.explicit_dirty = TRUE;
+	}
+}
+
+void
+on_product_list_select_row (GtkWidget *w, int row, int col, gpointer data)
+{
+	if (druid_data.state == STATE_PRODUCT)
+		druid_set_sensitive (TRUE, TRUE, TRUE);
+	druid_data.product = gtk_clist_get_row_data (GTK_CLIST (w), row);
+	gtk_entry_set_text (GTK_ENTRY (GET_WIDGET ("email-to-entry")),
+			    druid_data.product->bts->email);
+}
+
+void
+on_product_list_unselect_row (GtkWidget *w, int row, int col, gpointer data)
+{
+	if (druid_data.state == STATE_PRODUCT)
+		druid_set_sensitive (TRUE, FALSE, TRUE);
+	druid_data.product = NULL;
+}
+
+void
+on_component_list_select_row (GtkWidget *w, int row, int col, gpointer data)
+{
+	if (druid_data.state == STATE_COMPONENT)
+		druid_set_sensitive (TRUE, TRUE, TRUE);
+	druid_data.component = gtk_clist_get_row_data (GTK_CLIST (w), row);
+}
+
+void
+on_component_list_unselect_row (GtkWidget *w, int row, int col, gpointer data)
+{
+	if (druid_data.state == STATE_COMPONENT)
+		druid_set_sensitive (TRUE, FALSE, TRUE);
+	druid_data.component = NULL;
+}
+
+#if 0
 gboolean
 on_front_page_next (GtkWidget *page, GnomeDruid *druid)
 {
@@ -408,52 +416,6 @@ on_more_page_next (GnomeDruidPage *page, GnomeDruid *druid)
 	return TRUE;
 }
 
-static void
-on_refresh_button_clicked (GtkWidget *w, gpointer data)
-{
-	druid_data.explicit_dirty = TRUE;
-	start_gdb ();
-}
-
-gboolean
-on_less_page_prepare (GtkWidget *page, GtkWidget *druid)
-{
-	start_gdb ();
-	return FALSE;
-}
-
-gboolean
-on_contact_page_prepare (GnomeDruidPage *page, GnomeDruid *druid)
-{
-	gnome_druid_set_buttons_sensitive (druid, FALSE, TRUE, TRUE);	
-	return FALSE;
-}
-
-static void
-on_stop_button_clicked (GtkWidget *button, gpointer data)
-{
-	GtkWidget *w;
-	if (!druid_data.fd)
-		return;
-
-	w = gnome_question_dialog (_("gdb has not finished getting the "
-				     "debugging information.\n"
-				     "Kill the gdb process (the stack trace "
-				     "will be incomplete)?"),
-				   NULL, NULL);
-
-	if (GNOME_YES == gnome_dialog_run_and_close (GNOME_DIALOG (w))) {
-		if (druid_data.gdb_pid == 0) {
-			g_warning (_("gdb has already exited"));
-			return;
-		}
-		kill (druid_data.gdb_pid, SIGTERM);
-		stop_gdb ();		
-		kill (druid_data.app_pid, SIGCONT);
-		druid_data.explicit_dirty = TRUE;
-	}
-}
-
 gboolean
 on_version_page_back (GtkWidget *page, GnomeDruid *druid)
 {
@@ -470,55 +432,7 @@ on_version_page_back (GtkWidget *page, GnomeDruid *druid)
 	gnome_druid_set_page (druid, newpage);
 	return TRUE;
 }
-
-static void
-on_about_button_clicked (GtkWidget *button, gpointer data)
-{
-	static GtkWidget *about, *href;
-	static const char *authors[] = {
-		"Jacob Berkman  <jacob@bug-buddy.org>",
-		NULL
-	};
-
-	if (about) {
-		gdk_window_show (about->window);
-		gdk_window_raise (about->window);
-		return;
-	}
-		
-	about = gnome_about_new (_(PACKAGE), VERSION,
-				 _("The graphical bug reporting tool for GNOME."),
-				 authors,
-				 "Copyright (C) 1999, 2000 Jacob Berkman\n"
-				 "Copyright 2000 Helix Code, Inc.",
-				 BUDDY_ICONDIR"/bug-buddy.png");
-	gtk_signal_connect (GTK_OBJECT (about), "destroy",
-			    GTK_SIGNAL_FUNC (gtk_widget_destroyed),
-			    &about);
-
-	href = gnome_href_new ("http://bug-buddy.org/",
-			       _("The lame bug-buddy web page"));
-	gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (about)->vbox),
-			    href, FALSE, FALSE, 0);
-
-	gtk_widget_show (href);
-	gtk_widget_show (about);
-}
-
-static void
-on_help_button_clicked (GtkWidget *w, gpointer data)
-{
-	GnomeHelpMenuEntry help_entry = { "bug-buddy", "index.html"};
-	gnome_help_display(NULL, &help_entry);
-}
-
-gboolean
-on_the_druid_cancel (GtkWidget *w)
-{
-	save_config ();
-	gtk_main_quit ();
-	return FALSE;
-}
+#endif
 
 static gboolean
 on_timer (GtkProgress *progress)
@@ -534,6 +448,7 @@ on_timer (GtkProgress *progress)
 	return TRUE;
 }
 
+#if 0
 gboolean
 on_version_page_prepare (GnomeDruidPage *page, GnomeDruid *druid)
 {
@@ -732,7 +647,6 @@ on_complete_page_prepare (GtkWidget *page, GtkWidget *druid)
 	return FALSE;
 }
 
-
 gboolean
 on_complete_page_finish (GtkWidget *page, GtkWidget *druid)
 {
@@ -744,6 +658,7 @@ on_complete_page_finish (GtkWidget *page, GtkWidget *druid)
 	gtk_main_quit ();
 	return FALSE;
 }
+#endif
 
 void
 on_version_list_select_row (GtkCList *list, gint row, gint col,
@@ -752,12 +667,13 @@ on_version_list_select_row (GtkCList *list, gint row, gint col,
 	gchar *s;
 	druid_data.selected_row = row;
 	if (gtk_clist_get_text (list, row, 1, &s))
-		gtk_entry_set_text (GTK_ENTRY (VERSION_EDIT), s);
+		gtk_entry_set_text (GTK_ENTRY (GET_WIDGET ("version-entry")), s);
 	else
-		gtk_editable_delete_text (GTK_EDITABLE (VERSION_EDIT),
-					  0, -1);
+		gtk_editable_delete_text (
+			GTK_EDITABLE (GET_WIDGET ("the-version-entry")), 0, -1);
+			
 	gtk_clist_get_text (list, row, 0, &s);
-	gtk_label_set_text (GTK_LABEL (VERSION_LABEL), _(s));
+	gtk_label_set_text (GTK_LABEL (GET_WIDGET ("version-label")), _(s));
 }
 
 static void
@@ -787,7 +703,7 @@ void
 append_packages ()
 {
 	GtkWidget *w;
-	w = VERSION_LIST;
+	w = GET_WIDGET ("version-clist");
 
 	gtk_clist_freeze (GTK_CLIST (w));
 	g_slist_foreach (druid_data.packages, add_to_clist, w);
@@ -795,13 +711,13 @@ append_packages ()
 
 	stop_progress ();
 
-	w = GET_WIDGET ("skip_conf");
+	w = GET_WIDGET ("version-toggle");
 	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)))
 		return;
 
-	gnome_druid_set_page (GNOME_DRUID (druid_data.the_druid),
-			      GNOME_DRUID_PAGE (ACTION_PAGE));
+	on_druid_next_clicked (NULL, NULL);
 }
+
 void
 update_selected_row (GtkWidget *w, gpointer data)
 {
@@ -810,8 +726,8 @@ update_selected_row (GtkWidget *w, gpointer data)
 	if (druid_data.selected_row == -1)
 		return;
 	row = druid_data.selected_row;
-	s = gtk_entry_get_text (GTK_ENTRY (VERSION_EDIT));
-	gtk_clist_set_text (GTK_CLIST (VERSION_LIST), row, 1, s);
+	s = gtk_entry_get_text (GTK_ENTRY (GET_WIDGET ("the-version-entry")));
+	gtk_clist_set_text (GTK_CLIST (GET_WIDGET ("version-clist")), row, 1, s);
 }
 
 void
@@ -826,6 +742,7 @@ on_file_radio_toggled (GtkWidget *radio, gpointer data)
 	gtk_widget_set_sensitive (GTK_WIDGET (entry2), on);
 }
 
+#if 0
 gboolean
 on_action_page_prepare (GtkWidget *page, GnomeDruid *druid)
 {
@@ -938,7 +855,15 @@ make_pixmap_button (gchar *widget_name, gchar *text,
 	return w;
 	s2 = this_is_an_ugly_hack_for_kmaraas_and_the_rest_of_the_gnome_i18n_team[0];
 }
+#endif
 
+GtkWidget *
+stock_pixmap_buddy (gchar *w, char *n, char *a, int b, int c)
+{
+	return gnome_stock_pixmap_widget (NULL, n);
+}
+
+#if 0
 GtkWidget *
 make_anim (gchar *widget_name, gchar *imgname, 
 	   gchar *string2, gint size, gint freq)
@@ -969,7 +894,7 @@ init_bts_menu (void)
 	dir = opendir (BUDDY_DATADIR "/xml/");
 	if (!dir) {
 		s = g_strdup_printf (_("Could not open '%s'.\n"
-				       "Please make sure bug-buddy was "
+				       "Please make sure Bug Buddy was "
 				       "installed correctly."),
 				     BUDDY_DATADIR "/xml/");
 		w = gnome_error_dialog (s);
@@ -1010,19 +935,191 @@ init_bts_menu (void)
 		idx++;
 	}
 	closedir (dir);
-       
+
+#warning FIXME
+#if 0       
 	w = GET_WIDGET ("bts_menu");
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (w), m);
 	gtk_option_menu_set_history (GTK_OPTION_MENU (w), def);
-
+#endif
 	set_project (NULL, DEFAULT_BTS);
 	/* evil hack */
 	/*if (d) GTK_OPTION_MENU (w)->menu_item = d;*/
 }
+#endif
+
+void
+title_configure_size (GtkWidget *w, GtkAllocation *alloc, gpointer data)
+{
+	gnome_canvas_set_scroll_region (GNOME_CANVAS (w), 0.0, 0.0,
+					alloc->width, alloc->height);
+	gnome_canvas_item_set (druid_data.title_box,
+			       "x1", 0.0,
+			       "y1", 0.0,
+			       "x2", (gfloat)alloc->width,
+			       "y2", (gfloat)alloc->height,
+			       "width_units", 1.0, NULL);
+
+	gnome_canvas_item_set (druid_data.banner,
+			       "x", 15.0,
+			       "y", 24.0,
+			       "anchor", GTK_ANCHOR_WEST, NULL);
+
+	gnome_canvas_item_set (druid_data.logo,
+			       "x", (gfloat)(alloc->width - 48),
+			       "y", -2.0,
+			       NULL);
+}
+
+void
+side_configure_size (GtkWidget *w, GtkAllocation *alloc, gpointer data)
+{
+	gnome_canvas_set_scroll_region (GNOME_CANVAS (w), 0.0, 0.0,
+					alloc->width, alloc->height);
+	gnome_canvas_item_set (druid_data.side_box,
+			       "x1", 0.0,
+			       "y1", 0.0,
+			       "x2", (gfloat)alloc->width,
+			       "y2", (gfloat)alloc->height,
+			       "width_units", 1.0, NULL);
+
+	gnome_canvas_item_set (druid_data.side_image,
+			       "x", 0.0,
+			       "y", (gfloat)(alloc->height - 179),
+			       "width", 68.0,
+			       "height", 179.0, NULL);
+}
+
+#if 0
+static guchar *
+new_pixels (guchar *old_pixels, int width, int height, int rowstride, int bps, int n_channels)
+{
+	guchar *buf;
+	int size;
+
+	/* Calculate a semi-exact size.  Here we copy with full rowstrides;
+         * maybe we should copy each row individually with the minimum
+         * rowstride?
+         */
+
+        size = ((height - 1) * rowstride +
+                width * ((n_channels * bps + 7) / 8));
+
+        buf = malloc (size * sizeof (guchar));
+        if (!buf)
+                return NULL;
+
+        memcpy (buf, old_pixels, size);
+	return buf;
+}
+
+static ArtPixBuf *
+art_from_gdk (GdkPixbuf *pixbuf)
+{
+	ArtPixBuf *art;
+	guchar *pixels;
+
+	int width      = gdk_pixbuf_get_width     (pixbuf);
+	int height     = gdk_pixbuf_get_height    (pixbuf);
+	int rowstride  = gdk_pixbuf_get_rowstride (pixbuf);
+
+	pixels = new_pixels (gdk_pixbuf_get_pixels (pixbuf),
+			     width, height, rowstride,
+			     gdk_pixbuf_get_bits_per_sample (pixbuf),
+			     gdk_pixbuf_get_n_channels (pixbuf));
+
+	art = (gdk_pixbuf_get_has_alpha (pixbuf))
+		? art_pixbuf_new_rgba (pixels, width, height, rowstride)
+		: art_pixbuf_new_rgb  (pixels, width, height, rowstride);
+
+	return art;
+}
+#endif
+
+static void
+init_canvi (void)
+{
+	GdkPixbuf *pb;
+	GnomeCanvasItem *root;
+	GnomeCanvas *canvas;
+
+	canvas = GNOME_CANVAS (GET_WIDGET ("title-canvas"));
+	root = GNOME_CANVAS_ITEM (gnome_canvas_root (GNOME_CANVAS (canvas)));
+
+	druid_data.title_box = 
+		gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
+				       gnome_canvas_rect_get_type (),
+				       "fill_color", "black",
+				       "outline_color", "black", NULL);
+
+	druid_data.banner =
+		gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
+				       gnome_canvas_text_get_type (),
+				       "fill_color", "white",
+				       "font", "-adobe-helvetica-bold-r-normal-*-18-*-*-*-p-*-iso8859-1",
+				       "fontset", "-adobe-helvetica-bold-r-normal-*-18-*-*-*-p-*-iso8859-1,*-r-*",
+				       "anchor", GTK_ANCHOR_WEST,
+				       NULL);	
+
+
+	pb = gdk_pixbuf_new_from_file (BUDDY_DATADIR "/bug-core.png");
+	druid_data.logo =
+		gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
+				       GNOME_TYPE_CANVAS_PIXBUF,
+				       "pixbuf", pb, NULL);
+
+
+	/*******************************************************/
+	canvas = GNOME_CANVAS (GET_WIDGET ("side-canvas"));
+	root = GNOME_CANVAS_ITEM (gnome_canvas_root (GNOME_CANVAS (canvas)));
+	druid_data.side_box =
+		gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
+				       gnome_canvas_rect_get_type (),
+				       "fill_color", "black",
+				       "outline_color", "black", NULL);
+
+	pb = gdk_pixbuf_new_from_file (BUDDY_DATADIR "/bug-flower.png");
+
+	druid_data.side_image =
+		gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
+				       GNOME_TYPE_CANVAS_PIXBUF,
+				       "pixbuf", pb, NULL);
+
+
+	/*******************************************************/
+	canvas = GNOME_CANVAS (GET_WIDGET ("gdb-canvas"));
+	gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas), -12.0, -12.0, 12.0, 12.0);
+	root = GNOME_CANVAS_ITEM (gnome_canvas_root (GNOME_CANVAS (canvas)));
+	
+	pb = gdk_pixbuf_new_from_file (BUDDY_DATADIR "/bug-buddy.png");
+	druid_data.throbber_pb = gdk_pixbuf_scale_simple (pb, 24, 24, GDK_INTERP_BILINEAR);
+	gdk_pixbuf_unref (pb);
+
+	druid_data.throbber =
+		gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
+				       GNOME_TYPE_CANVAS_PIXBUF,
+				       "pixbuf", druid_data.throbber_pb,
+				       "x", -6.0,
+				       "y", -6.0,
+				       "height", 24.0,
+				       "width", 24.0,
+				       NULL);
+}
+
+static gint
+check_intro_skip (gpointer data)
+{
+	if (druid_data.already_run && 
+	    gtk_toggle_button_get_active (
+		    GTK_TOGGLE_BUTTON (GET_WIDGET ("intro-skip-toggle"))))
+		on_druid_next_clicked (NULL, NULL);
+
+	return FALSE;
+}
 
 /* there should be no setting of default values here, I think */
 static void
-init_ui ()
+init_ui (void)
 {
 	GtkWidget *w, *m;
 	gchar *s;
@@ -1030,45 +1127,16 @@ init_ui ()
 
 	glade_xml_signal_autoconnect (druid_data.xml);
 
-	w = GET_WIDGET ("the_druid");
-	druid_data.the_druid = w;
-
 	load_config ();
 
-	gtk_button_set_relief (GTK_BUTTON (GET_WIDGET ("already_href")),
-			       GTK_RELIEF_NONE);
+	init_canvi ();
 
-	m = gtk_menu_new ();
-	for (i = 0; severity[i]; i++) {
-		w = gtk_menu_item_new_with_label (_(severity[i]));
-		gtk_signal_connect (GTK_OBJECT (w), "activate",
-				    GTK_SIGNAL_FUNC (set_severity),
-				    GINT_TO_POINTER (i));
-		gtk_widget_show (w);
-		gtk_menu_append (GTK_MENU (m), w);
-	}
-
-	w = GET_WIDGET ("severity_option");
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (w), m);
-	gtk_option_menu_set_history (GTK_OPTION_MENU (w), 2);
-	druid_data.severity = 2;
-
-	m = gtk_menu_new ();
-	for (i = 0; bug_class[i][0]; i++) {
-		w = gtk_menu_item_new_with_label (_(bug_class[i][0]));
-		gtk_signal_connect (GTK_OBJECT (w), "activate",
-				    GTK_SIGNAL_FUNC (set_bug_class),
-				    GINT_TO_POINTER (i));
-		gtk_widget_show (w);
-		gtk_menu_append (GTK_MENU (m), w);
-	}
-	set_bug_class (NULL, GINT_TO_POINTER (druid_data.bug_class));
-
-	w = GET_WIDGET ("class_option");
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (w), m);
+	w = GET_WIDGET ("druid-notebook");
+	gtk_notebook_set_show_border (GTK_NOTEBOOK (w), FALSE);
+	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (w), FALSE);
 
 	/* dialog crash page */
-	w = APP_FILE;
+	w = GET_WIDGET ("gdb-binary-entry");
 	s = popt_data.app_file;
 	if (!s) {
 		s = getenv ("GNOME_CRASHED_APPNAME");
@@ -1081,7 +1149,7 @@ init_ui ()
 	if (s)
 		gtk_entry_set_text (GTK_ENTRY (w), s);
 
-	w = CRASHED_PID;
+	w = GET_WIDGET ("gdb-pid-entry");
 	s = popt_data.pid;
 	if (!s) {
 		s = getenv ("GNOME_CRASHED_PID");
@@ -1097,7 +1165,7 @@ init_ui ()
 	}
 
 	/* core crash page */
-	w = CORE_FILE;
+	w = GET_WIDGET ("gdb-core-entry");
 	if (popt_data.core_file) {
 		gtk_entry_set_text (GTK_ENTRY (w), popt_data.core_file);
 		druid_data.crash_type = CRASH_CORE;
@@ -1105,25 +1173,10 @@ init_ui ()
 
 	/* package version */
 	if (popt_data.package_ver) {
-		w = GET_WIDGET ("version_entry");
+		w = GET_WIDGET ("the-version-entry");
 		gtk_entry_set_text (GTK_ENTRY (w), popt_data.package_ver);
 	}
 
-        /* init some ex-radio buttons */
-	m = gtk_menu_new ();
-	for (i = 0; bug_type[i]; i++) {
-		w = gtk_menu_item_new_with_label (_(bug_type[i]));
-		gtk_signal_connect (GTK_OBJECT (w), "activate",
-				    GTK_SIGNAL_FUNC (update_bug_type),
-				    GINT_TO_POINTER (i));
-		gtk_widget_show (w);
-		gtk_menu_append (GTK_MENU (m), w);
-	}
-	w = GET_WIDGET ("bug_type_option");
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (w), m);
-	gtk_option_menu_set_history (GTK_OPTION_MENU (w), druid_data.bug_type);
-	update_bug_type (NULL, GINT_TO_POINTER (druid_data.bug_type));
-
         /* init some ex-radio buttons */
 	m = gtk_menu_new ();
 	for (i = 0; crash_type[i]; i++) {
@@ -1134,7 +1187,7 @@ init_ui ()
 		gtk_widget_show (w);
 		gtk_menu_append (GTK_MENU (m), w);
 	}
-	w = GET_WIDGET ("crash_type_option");
+	w = GET_WIDGET ("gdb-option");
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (w), m);
 	gtk_option_menu_set_history (GTK_OPTION_MENU (w), druid_data.crash_type);
 	update_crash_type (NULL, GINT_TO_POINTER (druid_data.crash_type));
@@ -1149,36 +1202,12 @@ init_ui ()
 		gtk_widget_show (w);
 		gtk_menu_append (GTK_MENU (m), w);
 	}
-	w = GET_WIDGET ("action_option");
+	w = GET_WIDGET ("email-option");
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (w), m);
 	gtk_option_menu_set_history (GTK_OPTION_MENU (w), druid_data.submit_type);
 	update_submit_type (NULL, GINT_TO_POINTER (druid_data.submit_type));
 
-	gtk_signal_connect (GTK_OBJECT (GET_WIDGET ("about_button")),
-			    "clicked",
-			    GTK_SIGNAL_FUNC (on_about_button_clicked),
-			    NULL);
-
-	gtk_signal_connect (GTK_OBJECT (GET_WIDGET ("help_button")),
-			    "clicked",
-			    GTK_SIGNAL_FUNC (on_help_button_clicked),
-			    NULL);
-
-	/* less page */
-	w = STOP_BUTTON;
-	gtk_signal_connect (GTK_OBJECT (w), "clicked",
-			    GTK_SIGNAL_FUNC (on_stop_button_clicked),
-			    NULL);
-	gtk_widget_set_sensitive (GTK_WIDGET (w), FALSE);
-
-	gtk_signal_connect (GTK_OBJECT (REFRESH_BUTTON), "clicked",
-			    GTK_SIGNAL_FUNC (on_refresh_button_clicked),
-			    NULL);
-
-	gnome_druid_set_page (GNOME_DRUID (druid_data.the_druid), 
-			      GNOME_DRUID_PAGE (GET_WIDGET ("contact_page")));
-
-	gnome_window_icon_set_from_default (GTK_WINDOW (GET_WIDGET ("druid_window")));
+	gnome_window_icon_set_from_default (GTK_WINDOW (GET_WIDGET ("druid-window")));
 }
 
 gint
@@ -1198,6 +1227,9 @@ main (int argc, char *argv[])
 	memset (&popt_data,  0, sizeof (popt_data));
 
 	druid_data.crash_type = CRASH_NONE;
+	druid_data.state = -1;
+
+	srand (time (NULL));
 
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
@@ -1206,38 +1238,37 @@ main (int argc, char *argv[])
 				    options, 0, NULL);
 	gnome_window_icon_set_default_from_file (BUDDY_ICONDIR"/bug-buddy.png");
 
+	gnome_vfs_init ();
 	glade_gnome_init ();
 
 	s = "bug-buddy.glade";
 	if (!g_file_exists (s))
 		s = BUDDY_DATADIR "/bug-buddy.glade";
 
-	gtk_widget_push_visual (gdk_imlib_get_visual ());
-	gtk_widget_push_colormap (gdk_imlib_get_colormap ());
-
-	druid_data.xml = glade_xml_new (s, "druid_window");
+	druid_data.xml = glade_xml_new (s, NULL);
 
 	if (!druid_data.xml) {
-		s = g_strdup_printf (_("Could not find '%s'.\n"
-				       "Please make sure bug-buddy was "
-				       "installed correctly."),
-				     BUDDY_DATADIR "/bug-buddy.glade");
-		w = gnome_error_dialog (s);
+		char *s2 = g_strdup_printf (_("Could not load '%s'.\n"
+					      "Please make sure Bug Buddy was "
+					      "installed correctly."), s);
+		w = gnome_error_dialog (s2);
 		gnome_dialog_run_and_close (GNOME_DIALOG (w));
 		return 0;
 	}
 
 	init_ui ();
 
-	init_bts_menu ();
+#if 0
+	load_bugzillas ();
+#endif
 
-	gtk_widget_show (GET_WIDGET ("druid_window"));
+	gtk_widget_show (GET_WIDGET ("druid-window"));
 
-	gtk_widget_pop_colormap ();
-	gtk_widget_pop_visual ();
+	gtk_idle_add (check_intro_skip, NULL);
+	
+	druid_set_state (STATE_INTRO);
 
 	gtk_main ();
 
 	return 0;
 }
-
